# find

start from root
make all thinks referring to root

# run

execution method:

* active execution
* active request
* worker
* callback

# reasonong
disconneceted realms
reason derivations 

reasoning is based on rules, e.g. transitive:

?x a ?y . ?y a ?z => ?x a ?z

or

?x oda:blocks ?y => ?y oda:blocked-by ?x

rule might generate another rule

emergent geometry


# ontology?

first but last
